retainedImageCount property
int
get
retainedImageCount
Decoded resources retained by this editor, deduplicated by source URI.
Implementation
int get retainedImageCount => _images.length;
Decoded resources retained by this editor, deduplicated by source URI.
int get retainedImageCount => _images.length;