DiagramVisualDetail enum

How much of a shape paints at its current on-screen size.

Only full paints a shape's text; compact and thumbnail omit it. thumbnail also omits connector markers and labels and shape ports.

Inheritance
Available extensions

Values

full → const DiagramVisualDetail

Everything paints.

compact → const DiagramVisualDetail

Below DiagramLodPolicy.compactBelowPixels but not yet a thumbnail: shape text is omitted.

thumbnail → const DiagramVisualDetail

Below DiagramLodPolicy.thumbnailBelowPixels: shape text, connector markers and labels, and ports are omitted.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DiagramVisualDetail>
A constant List of the values in this enum, in order of their declaration.