repaint property
Paint inputs of the content bands (camera, previews, caches).
Without structure the scene also rebuilds on every notification.
Implementation
final Listenable repaint;
Paint inputs of the content bands (camera, previews, caches).
Without structure the scene also rebuilds on every notification.
final Listenable repaint;