structure property

Listenable? structure
final

Inputs that change which elements and bands exist (scene, previews that substitute elements). When given, repaint only repaints the bands and repositions native slots; the band structure is rebuilt on structure and when the camera leaves the region composed last, not per frame.

Implementation

final Listenable? structure;