EffectPreviewPainter class final

Static thumbnail of an effect, rendered by the same registered definition as the canvas: along a short route, or on a small box when shape is true. Effects that present their element show the box scaled or faded.

ink draws the route and the box outline, surface fills the box and accent colors effects on the box; pass the colors of the panel the thumbnail sits on.

Inheritance

Constructors

EffectPreviewPainter(EffectDefinition definition, {EffectParticle particle = const EffectParticle.circle(), bool singleParticle = false, bool shape = false, Color ink = const Color(0xFF111111), Color surface = const Color(0xFFFFFFFF), Color accent = const Color(0xFF3B5BFF)})

Properties

accent → Color
final
definition → EffectDefinition
final
hashCode → int
The hash code for this object.
no setterinherited
ink → Color
final
particle → EffectParticle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder → SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
shape → bool
Previews the effect on a shape rather than along a connector.
final
singleParticle → bool
final
surface → Color
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) → bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant EffectPreviewPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited