RenderingOptions class final
Level of detail at low zoom and how painted content is retained, the options of RenderingExtension.
Constructors
- RenderingOptions({DiagramLodPolicy lod = const DiagramLodPolicy(), DiagramRenderPolicy render = const DiagramRenderPolicy()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- lod → DiagramLodPolicy
-
Which details paint at low zoom.
final
- render → DiagramRenderPolicy
-
Retain and raster tuning for canvas content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override