ChoiceValueField class final

A fixed set of text options, displayed as a choice control.

Inheritance

Constructors

ChoiceValueField({required String defaultValue, required List<String> values})

Properties

allowedValues → List<String>?
Null accepts any string. A supplied list must be nonempty and unique.
finalinherited
defaultValue → String
The value of a new shape. Null for a field every shape supplies, such as a drawing's ink, or one that is empty until set, such as an image.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(Object? value) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateDeclaration() → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited