DiagramAppearanceEditing class final

Inspector editing bounds; authored/imported appearance is not rewritten.

Constructors

DiagramAppearanceEditing({double maximumBorderWidth = 32, double maximumCornerRadius = 200})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumBorderWidth → double
final
maximumCornerRadius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited