DiagramArrowheadDefinition class final

Normalized terminal geometry shared by all renderers. X measures backward from the tip in units of marker height; Y measures perpendicular displacement in units of marker width.

Constructors

DiagramArrowheadDefinition({required ArrowheadKind kind, required String label, required Iterable<DiagramPoint> path, bool closed = false, bool filled = false, double bodyTrim = 1})

Properties

bodyTrim → double
Connector body clearance, in units of the marker height.
final
closed → bool
final
filled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
kind → ArrowheadKind
final
label → String
final
path → List<DiagramPoint>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited