DiagramConnectorBendEditor class abstract interface

Optional route behavior. A provider may extend other installed routes, such as promoting a straight segment to a curve through its midpoint handle.

Properties

bendableRoutes → Set<ConnectorRoute>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bend(DiagramConnectorBendRequest request) → ConnectorElement
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited