endDirection property
Forward path tangents at authored terminals. After owner clipping the engine derives directions from the remaining sampled path instead.
Implementation
final DiagramPoint? startDirection, endDirection;
Forward path tangents at authored terminals. After owner clipping the engine derives directions from the remaining sampled path instead.
final DiagramPoint? startDirection, endDirection;