DiagramConnectorRoutePostProcessor class abstract interface

Batch post-processing for routes planned together. Returned waypoints replace the planned ones by connector id and must keep both terminals; omitted ids keep their planned route.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postProcess(List<DiagramPlannedConnectorRoute> routes, Iterable<DiagramRect> obstaclesWithin(DiagramRect bounds)) → Map<String, List<DiagramPoint>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited