DiagramContentCodec class abstract interface

Versioned persistence of one extension-owned authored content type.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter
version → int
no setter

Methods

decode(Map<String, Object?> data, int version, DiagramContentCodecContext context) → TextStoryContent
encode(TextStoryContent content, DiagramContentCodecContext context) → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited