codecs property
Persistence of installed content and text attributes, for document format adapters such as the JSON codec.
Implementation
late final DiagramModelCodecs codecs;
Persistence of installed content and text attributes, for document format adapters such as the JSON codec.
late final DiagramModelCodecs codecs;