DiagramFreehandTool class final

Draws a freehand stroke that follows the pointer.

Inheritance

Constructors

DiagramFreehandTool()
const

Properties

creationShapeType → String
Registered shape whose appearance can be configured before creation.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hover(DiagramToolContext context, DiagramToolPointer pointer) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointerDown(DiagramToolContext context, DiagramToolPointer pointer) → void
override
toString() → String
A string representation of this object.
inherited
validate(ShapeRegistry shapes) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited