DiagramKeyArguments typedef

DiagramKeyArguments = Map<String, Object?> Function(DiagramController controller, String? elementId)

Computes a bound verb's arguments when its chord is pressed, from the current state of controller and the targeted elementId.

Implementation

typedef DiagramKeyArguments = Map<String, Object?> Function(
  DiagramController controller,
  String? elementId,
);