slotId property
textType matches the registered type of the active text slot and is valid only for DiagramKeyScope.text.
Implementation
final String? shapeType, textType, slotId;
textType matches the registered type of the active text slot and is valid only for DiagramKeyScope.text.
final String? shapeType, textType, slotId;