DiagramMeasuredTextLine class final

A paragraph shaper's line before shared slot placement and alignment.

Constructors

DiagramMeasuredTextLine({required int start, required int end, required double left, required double width, required double height, required double baseline, required double intrinsicWidth, required double fontSize, DiagramTextLineGeometry? geometry, ResolvedTextFontFamilies? fontFamilies})
const

Properties

baseline → double
Alphabetic baseline measured from this visual line's top.
final
defaultFontFamily → String?
no setter
end → int
final
fontFamilies → ResolvedTextFontFamilies?
final
fontSize → double
final
geometry → DiagramTextLineGeometry?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
intrinsicWidth → double
final
left → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited