DiagramModelCodecs class final

Frozen codecs shared by a model registry and its document format adapters: authored contents by content type and texts by the type of the attributes they persist.

Constructors

DiagramModelCodecs({Iterable<DiagramContentCodec> contents = const [], Iterable<DiagramTextCodec> texts = const []})
factory
DiagramModelCodecs.empty()
const

Properties

contents → Map<String, DiagramContentCodec>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texts → Map<String, DiagramTextCodec>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited