DiagramPortShapeRegistry class final

Frozen named port geometry. Duplicate identities reject assembly.

Properties

definitions → Map<PortShape, DiagramPortShapeDefinition>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
require(PortShape shape) → DiagramPortShapeDefinition
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited