check method
Null when value is acceptable, otherwise the reason it is not.
Implementation
String? check(T value) => _check?.call(value);
Null when value is acceptable, otherwise the reason it is not.
String? check(T value) => _check?.call(value);