isWritable property
bool
get
isWritable
Whether the property changes subjects, rather than only showing them.
Implementation
bool get isWritable => verb != null || _update != null;
Whether the property changes subjects, rather than only showing them.
bool get isWritable => verb != null || _update != null;