summarize method
Short text describing value, for custom values without an editor.
Implementation
String summarize(T value) => _summary?.call(value) ?? '$value';
Short text describing value, for custom values without an editor.
String summarize(T value) => _summary?.call(value) ?? '$value';