update method

S update(
  1. S subject,
  2. T value
)

subject with value, for a property of a value, such as a label or the options, rather than of an element.

Implementation

S update(S subject, T value) {
  final update = _update;
  if (update == null) throw StateError('$key does not update a value.');
  return update(subject, value);
}