options property
DiagramOptions
get
options
The installed extensions' options, the canvas bounds and the default font family.
Implementation
DiagramOptions get options => controller.state.options;
The installed extensions' options, the canvas bounds and the default font family.
DiagramOptions get options => controller.state.options;