text property
DiagramTextSubject?
get
text
The text being formatted, when the selection has any.
Implementation
DiagramTextSubject? get text => _text;
The text being formatted, when the selection has any.
DiagramTextSubject? get text => _text;