DiagramPropertySpacing class final
The space around a property section: lead before it, header under its title and trail after it. A null trail follows a titled section with a section gap and an untitled one with a control gap.
Constructors
-
DiagramPropertySpacing({List<
DiagramPropertyGap> lead = const [], List<DiagramPropertyGap> header = const [DiagramPropertyGap.control], List<DiagramPropertyGap> ? trail}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ List<
DiagramPropertyGap> -
final
-
lead
→ List<
DiagramPropertyGap> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trail
→ List<
DiagramPropertyGap> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited