DiagramShapeTextTarget class final

The story of a ShapeElement.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
owner → ShapeElement
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
story → TextStory
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceStory(TextStory story) → ShapeElement
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited