DiagramStandaloneTextTarget class final
The story of a TextElement.
- Inheritance
-
- Object
- DiagramTextTarget
- DiagramStandaloneTextTarget
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → TextElement
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- story → TextStory
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceStory(
TextStory story) → TextElement -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited