handleKey method
Handles a key chord on this text, or returns null to leave it to other handlers.
Implementation
DiagramTextKeyResult? handleKey(
DiagramTextKey key,
DiagramTextKeyContext context,
) => null;
Handles a key chord on this text, or returns null to leave it to other handlers.
DiagramTextKeyResult? handleKey(
DiagramTextKey key,
DiagramTextKeyContext context,
) => null;