markers property
DiagramTextMarkers?
get
markers
List and checklist markers, or null when this text draws none.
Implementation
DiagramTextMarkers? get markers => null;
List and checklist markers, or null when this text draws none.
DiagramTextMarkers? get markers => null;