multiline property
bool
get
multiline
Whether the text spans several lines: Enter starts a new line and the value is committed when editing ends.
Implementation
bool get multiline => maxLines > 1;
Whether the text spans several lines: Enter starts a new line and the value is committed when editing ends.
bool get multiline => maxLines > 1;