text property
The text filling this region, which presents its paragraphs and markers; null lays out plain text.
Implementation
final DiagramTextDefinition? text;
The text filling this region, which presents its paragraphs and markers; null lays out plain text.
final DiagramTextDefinition? text;