formatRuns method
Formats the inspected runs, or the next typing style at a caret.
Implementation
DiagramTextSubject formatRuns(
TextRun Function(TextRun run) format, {
String? label,
}) => _with(_DiagramRunFormat(format, label));
Formats the inspected runs, or the next typing style at a caret.
DiagramTextSubject formatRuns(
TextRun Function(TextRun run) format, {
String? label,
}) => _with(_DiagramRunFormat(format, label));