DiagramTextTarget class sealed
Exact canonical story ownership, independent of its mounted editor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → DiagramElement
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- story → TextStory
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceStory(
TextStory story) → DiagramElement -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
DiagramElement? owner, String storyId) → DiagramTextTarget?