DiagramToggleStyle enum

How a toggle is presented.

Inheritance
Available extensions

Values

standard → const DiagramToggleStyle

A labeled switch.

compact → const DiagramToggleStyle

A labeled switch at compact density.

button → const DiagramToggleStyle

An icon button in a toolbar row, showing the property's icon.

An icon button in its group's header, showing the property's icon.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DiagramToggleStyle>
A constant List of the values in this enum, in order of their declaration.