DiagramToolContext class abstract interface

Input adapters implement mechanics; tools compose them without private state.

Properties

hashCode → int
The hash code for this object.
no setterinherited
publication → DiagramPublication
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginConnection(DiagramToolPointer pointer, {String connectorType = 'connector'}) → void
beginErasing(DiagramToolPointer pointer) → void
beginFreehand(DiagramToolPointer pointer) → void
beginGesture(DiagramToolPointer pointer, DiagramToolGesture gesture) → void
beginSelection(DiagramToolPointer pointer) → void
beginShape(DiagramToolPointer pointer, {required String shapeType, bool editAfterCreation = false, bool autoWidthOnClick = false}) → void
hoverConnection(DiagramToolPointer pointer) → void
hoverSelection(DiagramToolPointer pointer) → void
nextId(String prefix) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
perform(Iterable<String> ids, String verb, [Map<String, Object?> args = const {}]) → EditResult
Performs a verb, as DiagramController.perform does.
setCursor(DiagramToolCursor cursor) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited