returnToDefault property
Returns to the registry default after an admitted dispatch or gesture commit. A denied dispatch or commit retains the tool for retry.
Implementation
final bool returnToDefault;
Returns to the registry default after an admitted dispatch or gesture commit. A denied dispatch or commit retains the tool for retry.
final bool returnToDefault;