DiagramToolPointer class final

Pointer coordinates already projected through the canonical camera.

Constructors

DiagramToolPointer({required int pointerId, required DiagramPoint screen, required DiagramPoint world, double? pressure, bool shiftPressed = false, Duration timeStamp = Duration.zero})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pointerId → int
final
pressure → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screen → DiagramPoint
final
shiftPressed → bool
final
timeStamp → Duration
final
world → DiagramPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited