DiagramVerbDerived class final

A verb that derives its values, such as aligning a selection. A setter, reversedBy, expresses the result in reverse.

Inheritance

Constructors

DiagramVerbDerived({required String reversedBy})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reversedBy → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited