path property
Path
get
path
The connector route, or the shape outline, in world coordinates.
Implementation
Path get path => Path.from(_path);
The connector route, or the shape outline, in world coordinates.
Path get path => Path.from(_path);