holds property
Whether the effect plays once over its period and then holds its last frame until stopped, like a fade, instead of cycling.
Implementation
final bool holds;
Whether the effect plays once over its period and then holds its last frame until stopped, like a fade, instead of cycling.
final bool holds;