EffectProperty enum

Effect values an inspector may offer for editing.

Inheritance
Available extensions

Values

particle → const EffectProperty
color → const EffectProperty
gradient → const EffectProperty
speed → const EffectProperty
baseOpacity → const EffectProperty
opacity → const EffectProperty
size → const EffectProperty
width → const EffectProperty
count → const EffectProperty
direction → const EffectProperty
scale → const EffectProperty
waveform → const EffectProperty
repeat → const EffectProperty
delay → const EffectProperty
target → const EffectProperty
mode → const EffectProperty
amount → const EffectProperty
spread → const EffectProperty
dim → const EffectProperty
fade → const EffectProperty

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<EffectProperty>
A constant List of the values in this enum, in order of their declaration.