EffectRegistry class final

One registry serves built-in and custom effects, admission and inspector UI.

A registry holds exactly the supplied definitions; spread standard's definitions to include the built-in effects.

Constructors

EffectRegistry(Iterable<EffectDefinition> definitions)

Properties

definitions → Iterable<EffectDefinition>
no setter
forConnectors → Iterable<EffectDefinition>
The definitions that can play along a connector.
no setter
forShapes → Iterable<EffectDefinition>
The definitions that can play on a shape.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(EffectKind kind) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
require(EffectKind kind) → EffectDefinition
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](EffectKind kind) → EffectDefinition?

Static Properties

standard → EffectRegistry
Flow, pulse, halo, scale and fade.
final