invalidateFonts method
void
invalidateFonts()
Call after the host changes available fonts, then refresh the diagram layout.
Implementation
void invalidateFonts() {
_cache.clear();
_revision++;
}
Call after the host changes available fonts, then refresh the diagram layout.
void invalidateFonts() {
_cache.clear();
_revision++;
}