GraphLayoutNode class final
Constructors
- GraphLayoutNode({required String id, required DiagramSize size, DiagramPoint? position, bool pinned = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- pinned → bool
-
final
- position → DiagramPoint?
-
The node's top-left corner, required when pinned.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → DiagramSize
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited