defaultValue property

  1. @override
Object? get defaultValue
override

The value of a new shape. Null for a field every shape supplies, such as a drawing's ink, or one that is empty until set, such as an image.

Implementation

@override
Object? get defaultValue => null;