InkValueField class final

A freehand stroke, stored as DiagramInk.toValue. Every shape supplies its own ink; there is no default stroke.

Inheritance

Constructors

InkValueField()
const

Properties

defaultValue → Object?
The value of a new shape. Null for a field every shape supplies, such as a drawing's ink, or one that is empty until set, such as an image.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(Object? value) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateDeclaration() → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited