PortPlacement class final

A closed placement expression for a port relative to the primary frame or a named layer.

Constructors

PortPlacement.normalized({required DiagramPoint? anchor, required DiagramPoint? outwardNormal, String? targetLayerId})
const
PortPlacement.sideDistanceFromEnd({required PortSide side, required double offset, String? targetLayerId})
const
PortPlacement.sideDistanceFromStart({required PortSide side, required double offset, String? targetLayerId})
const
PortPlacement.sideFraction({required PortSide side, double offset = 0.5, String? targetLayerId})
const

Properties

anchor → DiagramPoint?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → PortPlacementKind
final
offset → double
final
outwardNormal → DiagramPoint?
final
resolvedOutwardNormal → DiagramPoint
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side → PortSide?
final
targetLayerId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveAnchor(DiagramRect target) → DiagramPoint
toString() → String
A string representation of this object.
inherited
validate(String owner, Set<String> layerIds) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited