connectedFill property
Fill of the inset marker drawn while a connector binds the port; the stroke colour when omitted.
Implementation
final DiagramColor? connectedFill;
Fill of the inset marker drawn while a connector binds the port; the stroke colour when omitted.
final DiagramColor? connectedFill;