ResolvedArrowhead class final
Resolved terminal-marker geometry shared by paint, hit testing and export.
Constructors
-
ResolvedArrowhead({required Arrowhead source, required DiagramPoint tip, required DiagramPoint backCenter, required DiagramPoint firstWing, required DiagramPoint secondWing, required List<
DiagramPoint> path, required bool closed, required bool filled, required double bodyTrimDistance})
Properties
- backCenter → DiagramPoint
-
final
- bodyTrimDistance → double
-
final
- closed → bool
-
final
- filled → bool
-
final
- firstWing → DiagramPoint
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hull
→ List<
DiagramPoint> -
no setter
-
path
→ List<
DiagramPoint> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondWing → DiagramPoint
-
final
- source → Arrowhead
-
final
- tip → DiagramPoint
-
final
Methods
-
hitTest(
DiagramPoint point, {double tolerance = 5}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited