routeDiagnostic property
Why the published route is degraded, such as a stale planned route or a provider fallback. Null for an ordinary route.
Implementation
final DiagramConnectorRouteDiagnostic? routeDiagnostic;
Why the published route is degraded, such as a stale planned route or a provider fallback. Null for an ordinary route.
final DiagramConnectorRouteDiagnostic? routeDiagnostic;