startBindingPosition property
Authored attachment locations, distinct from the clipped visible route.
Implementation
final DiagramPoint startBindingPosition;
Authored attachment locations, distinct from the clipped visible route.
final DiagramPoint startBindingPosition;