ResolvedConnectorBundleBadge class final

One count badge at a collapsed bundle attachment.

Constructors

ResolvedConnectorBundleBadge({required DiagramRect bounds, ResolvedTextStory? text})
const

Properties

bounds → DiagramRect
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → ResolvedTextStory?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited