A content-owned group of lines and its spatial adjacency rules.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adjacentPosition(
DiagramTextPosition position, ResolvedTextLine current, ResolvedTextStory text, DiagramTextNavigationDirection direction) → DiagramTextPosition -
lines(
ResolvedTextStory text) → List< ResolvedTextLine> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited