textFor method

DiagramTextDefinition textFor(
  1. TextParagraph paragraph
)

The text filling the slot of paragraph, which decides what the paragraph admits and how it edits.

Implementation

DiagramTextDefinition textFor(TextParagraph paragraph) =>
    _textFor(paragraph.effectiveSlotId);