behavior property

ShapeBehavior get behavior

What a person may do to this element now: its declared behavior, narrowed while it is locked, collapsed or holds constraining content.

Implementation

ShapeBehavior get behavior;