translated method
This outline moved by delta, or null when the implementation cannot
translate itself. Resolution then re-runs the full shape pipeline.
Implementation
ResolvedOutline? translated(DiagramPoint delta) => null;
This outline moved by delta, or null when the implementation cannot
translate itself. Resolution then re-runs the full shape pipeline.
ResolvedOutline? translated(DiagramPoint delta) => null;