ResolvedPathSample class final

A point on a resolved route: its position, the unit tangent there and its fraction of the route's length. The normal is the tangent rotated a quarter turn.

Constructors

ResolvedPathSample({required DiagramPoint position, required DiagramPoint tangent, required double fraction})
const

Properties

fraction → double
final
hashCode → int
The hash code for this object.
no setterinherited
normal → DiagramPoint
no setter
position → DiagramPoint
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tangent → DiagramPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited