collapseControlBounds property
Local bounds of the header control, resolved beside an external title.
Implementation
final DiagramRect? collapseControlBounds;
Local bounds of the header control, resolved beside an external title.
final DiagramRect? collapseControlBounds;