ResolvedShapeWidgetSlot class final

Pure geometry for mounting a widget; never a durable widget instance.

Constructors

ResolvedShapeWidgetSlot({required ShapeWidgetLayerDefinition definition, required DiagramRect bounds})
const

Properties

bounds → DiagramRect
final
definition → ShapeWidgetLayerDefinition
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited