ResolvedTextFontFamilies class final
Immutable font fallback order retained by a native text shaper for output.
Constructors
-
ResolvedTextFontFamilies(Iterable<
String> values)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited