field property
The NumberValueField this handle sets; its minimum, maximum and integer constraint bound the handle.
Implementation
final String field;
The NumberValueField this handle sets; its minimum, maximum and integer constraint bound the handle.
final String field;