resizesWidth property
bool
get
resizesWidth
Whether resizing can change the width, and the height.
Implementation
bool get resizesWidth => resizable;
Whether resizing can change the width, and the height.
bool get resizesWidth => resizable;