createContent method
Creates authored content once when a new owner is created. A visual-only provider may leave the region without a story payload.
Implementation
TextStoryContent? createContent(String elementId) => null;
Creates authored content once when a new owner is created. A visual-only provider may leave the region without a story payload.
TextStoryContent? createContent(String elementId) => null;