A portable provider for a registered structured content region.
Properties
Methods
-
canDeleteSelection(
DiagramController store, ContentSelection selection) → bool -
createSession(
DiagramTextLayoutEngine textLayout) → ShapeContentLayoutSession -
deleteSelection(
DiagramController store, ContentSelection selection) → EditResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited