ShapeContentPart class abstract
A portable extension leaf lowers into registered content declarations, such as a table.
Constructors
- ShapeContentPart()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumSize → DiagramSize
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildContentLayers(
ShapeBoundsDefinition bounds, String id) → Iterable< ShapeContentLayerDefinition> -
minimumSizeFor(
FramedElement shape, Map< String, double> textHeights) → DiagramSize -
inherited
-
named(
String name) → ShapePart -
Reuses this part with namespaced text slots and explicitly named surfaces.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withNamespace(
String name) → ShapeContentPart
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited