adjustments property
On-canvas handles bound to numeric values, such as an arrow's head length.
Implementation
final List<ShapeAdjustment> adjustments;
On-canvas handles bound to numeric values, such as an arrow's head length.
final List<ShapeAdjustment> adjustments;