affordances property

List<ShapeAffordance> affordances
final

On-canvas controls beside the selected shape, such as a card's optional tag, each performing one of the shape's verbs.

Implementation

final List<ShapeAffordance> affordances;