ShapeOptionalSlotAffordance class final

Adds or removes the optional text of slotId, shown beside the text of anchorSlotId, through the addSlot and removeSlot verbs, as one undoable edit. The text is present while it is nonblank, or while the boolean value enabledValueKey is true when the shape stores one.

Inheritance

Constructors

ShapeOptionalSlotAffordance({required String slotId, required String anchorSlotId, required String label, required String initialText, String? enabledValueKey})
const

Properties

anchorSlotId → String
final
enabledValueKey → String?
final
hashCode → int
The hash code for this object.
no setterinherited
initialText → String
The text an added slot starts with.
final
label → String
What the text is, as in "Add tag".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited