ShapeRow class final
Children stretch across the row; unspecified widths share remaining space.
Properties
-
children
→ List<
ShapePart> -
finalinherited
- gap → double
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontal → bool
-
finalinherited
- minimumSize → DiagramSize
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
minimumSizeFor(
FramedElement shape, Map< String, double> textHeights) → DiagramSize -
inherited
-
named(
String name) → ShapePart -
Reuses this part with namespaced text slots and explicitly named surfaces.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited