contentHeightSlot property

String? contentHeightSlot
final

Sizes this part to the required height of the content, such as a table, in that slot, so a section is exactly as tall as its rows.

Implementation

final String? contentHeightSlot;