ShapeStack class final
Paints parts back-to-front in the same bounds.
Constructors
-
ShapeStack(Iterable<
ShapePart> children)
Properties
-
children
→ List<
ShapePart> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumSize → DiagramSize
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
minimumSizeFor(
FramedElement shape, Map< String, double> textHeights) → DiagramSize -
override
-
named(
String name) → ShapePart -
Reuses this part with namespaced text slots and explicitly named surfaces.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited