onInteract property
The verb or host interaction a pointer on this region performs, such
as an image's choose-image.
Implementation
final String? onInteract;
The verb or host interaction a pointer on this region performs, such
as an image's choose-image.
final String? onInteract;