ShapeSurfaceLayerDefinition class final

A compiled ShapeSurface.

Inheritance

Constructors

ShapeSurfaceLayerDefinition({required String id, required ShapeBoundsDefinition bounds, required ShapeOutline? outline, required ShapeStyle style, ShapeVisibility? visibleWhen, String? onInteract})

Properties

bounds → ShapeBoundsDefinition
finalinherited
cursor → ShapeLayerCursor
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
interactionId → String?
no setteroverride
onInteract → String?
final
outline → ShapeOutline?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ShapeStyle
final
visibleWhen → ShapeVisibility?
final

Methods

isVisible(FramedElement shape) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited