editable property

bool editable
final

False keeps people from editing this text on the canvas. Host code and verbs, such as setText, still set any text; text is only the text a new shape starts with.

Implementation

final bool editable;