ShapeTextCreation class final

Text sizing defaults for authored frames and click-created elements. Explicit creation intents may override these defaults.

Constructors

ShapeTextCreation({DiagramTextSizingMode sizingMode = DiagramTextSizingMode.fixedWidth, DiagramTextSizingMode? clickSizingMode})
const

Properties

clickSizingMode → DiagramTextSizingMode
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizingMode → DiagramTextSizingMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(ShapeBehavior behavior) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited