ShapeValueToggleAffordance class final

Switches the boolean value valueKey through the setter verb, passing the opposite value as argument, as one undoable edit.

Inheritance

Constructors

ShapeValueToggleAffordance({required String verb, required String argument, required String valueKey, required String label})
const

Properties

argument → String
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
What the value shows, as in "Add secondary section".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueKey → String
final
verb → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited