isValue property
bool
get
isValue
Whether the condition is a boolean value rather than a slot's content.
Implementation
bool get isValue => this is _ValueVisibility;
Whether the condition is a boolean value rather than a slot's content.
bool get isValue => this is _ValueVisibility;