beginValueEdit method
A slider can preview repeatedly, then commit once or cancel the edit.
Implementation
ShapeValueEdit beginValueEdit() {
if (!enabled) throw StateError('Shape widget is read-only');
return _onBeginValueEdit();
}
A slider can preview repeatedly, then commit once or cancel the edit.
ShapeValueEdit beginValueEdit() {
if (!enabled) throw StateError('Shape widget is read-only');
return _onBeginValueEdit();
}