alignable property
bool
get
alignable
Whether the paragraph takes its own alignment. Structure that aligns by itself, such as a list item, declines it.
Implementation
bool get alignable => true;
Whether the paragraph takes its own alignment. Structure that aligns by itself, such as a list item, declines it.
bool get alignable => true;