appearance method
The appearance of a run with these attributes over inherited.
Implementation
TextRunAppearance appearance(TextRunAppearance inherited) => inherited;
The appearance of a run with these attributes over inherited.
TextRunAppearance appearance(TextRunAppearance inherited) => inherited;