NavigationOptions class final

Viewport navigation and keyboard movement of the selection, the options of NavigationExtension. Without one installed a canvas uses these defaults.

Constructors

const

Properties

edgePadding → double
Logical pixels inside each viewport edge that activate drag auto-pan.
final
edgePanEnabled → bool
Edge panning during pointer gestures and keyboard movement. Rotation never edge-pans, even when this option is enabled.
final
fitOnAttach → bool
Whether a canvas shows all content when it first has a viewport.
final
hashCode → int
The hash code for this object.
no setteroverride
keyboardStep → double
World units to move selected elements per Arrow key press or repeat.
final
maximumPanSpeed → double
Logical pixels per second at or beyond the edge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shiftMultiplier → double
final

Methods

copyWith({bool? edgePanEnabled, double? edgePadding, double? maximumPanSpeed, double? keyboardStep, double? shiftMultiplier, bool? fitOnAttach}) → NavigationOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
override