DiagramFreehandPreview class final
Lightweight ink owned by the active pointer gesture.
The points are intentionally not part of the canonical document or resolved scene. They are consumed only during paint and are materialized as one canonical freehand shape when the gesture commits.
Constructors
-
DiagramFreehandPreview({required List<
DiagramPoint> points, required ShapeStyle style, List<double> pressures = const []})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
points
→ List<
DiagramPoint> -
final
-
pressures
→ List<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ShapeStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited