DiagramConnectorBendRequest class final
Canonical baseline and resolved world coordinates for a bend gesture.
Constructors
- DiagramConnectorBendRequest({required ConnectorElement connector, required DiagramPoint start, required DiagramPoint end, required DiagramPoint position, required double snapDistance})
-
const
Properties
- connector → ConnectorElement
-
final
- end → DiagramPoint
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → DiagramPoint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapDistance → double
-
final
- start → DiagramPoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited