DiagramConnectorControlRequest class final
Immutable gesture baseline passed to an installed route control editor.
Constructors
-
DiagramConnectorControlRequest({required ConnectorElement connector, required Iterable<
DiagramPoint> controls, required int index, required DiagramPoint start, required DiagramPoint end, required DiagramPoint position, required double snapDistance, required bool gridSnapped, bool snapAngle = false, double rotationSnap = 15})
Properties
- connector → ConnectorElement
-
final
-
controls
→ List<
DiagramPoint> -
final
- end → DiagramPoint
-
final
- gridSnapped → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- position → DiagramPoint
-
final
- rotationSnap → double
-
The rotation snap increment in degrees.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapAngle → bool
-
Constrain the control arm to rotationSnap degree increments.
final
- snapDistance → double
-
final
- start → DiagramPoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited