DiagramConnectorEditing class final
Connector inspector bounds, independent of authored/imported route intent.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumArrowSize → double
-
final
- maximumCornerRadius → double
-
final
- maximumPortExtension → double
-
final
- maximumPortSpacing → double
-
final
- maximumStrokeWidth → double
-
final
- minimumArrowSize → double
-
final
- minimumStrokeWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited