DiagramConnectorRoutePlanningContext class final
Read-only scene queries available during an explicit route planning command.
Constructors
-
DiagramConnectorRoutePlanningContext({required Iterable<
DiagramRect> obstaclesWithin(DiagramRect bounds), required bool allowsSegment(DiagramPoint start, DiagramPoint end, double clearance)}) -
const
Properties
- allowsSegment → bool Function(DiagramPoint start, DiagramPoint end, double clearance)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
obstaclesWithin
→ Iterable<
DiagramRect> Function(DiagramRect bounds) -
Spatial-index backed obstacle bounds intersecting a region, excluding the
connector's terminal owners and containers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited