createMoveAdjuster method
Adjusts selection moves on the canvas of controller, such as snapping
them into alignment, or null. Created when the canvas mounts; adjusters
apply in installation order and the host shows their
DiagramCanvasExtensionHost.moveGuides.
Implementation
DiagramMoveAdjuster? createMoveAdjuster(DiagramController controller) => null;