DiagramMoveAdjustment class final

The movement a DiagramMoveAdjuster settles on, with the guides that explain it.

Constructors

DiagramMoveAdjustment(DiagramPoint delta, [List<DiagramMoveGuide> guides = const []])
const

Properties

delta → DiagramPoint
final
guides → List<DiagramMoveGuide>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited