DiagramNumberPresentation class final
- Inheritance
-
- Object
- DiagramPropertyPresentation
- DiagramNumberPresentation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → double
-
final
- min → double
-
final
- precision → int?
-
Displayed decimal places; null follows step.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → double
-
final
- style → DiagramNumberStyle
-
final
- unit → String
-
final
Methods
-
boundsFor(
Object? subject) → (double, double) -
The bounds for
subject: min and max unless the property computes them from the subject. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited