Output adapter for an immutable snapshot supplied by the owning engine. The snapshot type is a parameter so foundational types never depend on session or resolved-layout implementations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportPng(
Snapshot snapshot, PngOptions options) → Future< PngSnapshot> -
Renders
snapshotas PNG, cropped to PngOptions.bounds. -
exportSvg(
Snapshot snapshot, SvgOptions options) → Future< SvgSnapshot> -
Renders
snapshotas SVG, cropped to SvgOptions.bounds. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited