DiagramPairPresentation class final
An x/y point or a width/height size, edited axis by axis.
- Inheritance
-
- Object
- DiagramPropertyPresentation
- DiagramPairPresentation
Properties
- axisLabels → (String, String)
-
final
- editableAxes → (bool, bool)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → double
-
final
- minimum → (double, double)
-
The least value of each axis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → double
-
final
- unit → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited