DiagramParagraphSplitPlan class final

Paragraph templates whose identities, content, and regions remain unchanged. A missing trailing template transforms the paragraph without splitting it.

Constructors

DiagramParagraphSplitPlan({required TextParagraph leading, TextParagraph? trailing})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
leading → TextParagraph
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailing → TextParagraph?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited