Shapes and lays out a TextStory into a ResolvedTextStory.
layout places the story within clipBounds and, for each region given, the
blocks that target that region's slot. Implementations may use platform text
shaping or fixed metrics.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
layout(
{required TextStory story, required DiagramRect clipBounds, required int revisionKey, List< DiagramTextRegionLayout> regions = const []}) → ResolvedTextStory -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited