DiagramToolRegistry class final
The registered tools, looked up by identity or shortcut.
Construction rejects duplicate or empty identities, empty labels and groups, and shortcuts that are duplicated or not a single character. defaultTool must be registered.
Constructors
-
DiagramToolRegistry(Iterable<
DiagramToolDefinition> definitions, {required DiagramTool defaultTool})
Properties
- defaultTool → DiagramTool
-
final
-
definitions
→ Iterable<
DiagramToolDefinition> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
forShortcut(
DiagramShortcut shortcut) → DiagramToolDefinition? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
require(
DiagramTool id) → DiagramToolDefinition -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited