animated property
Whether the effect changes over time. Effects that only change when they are updated set this to false, so the canvas does not tick frames for them.
Implementation
final bool animated;
Whether the effect changes over time. Effects that only change when they are updated set this to false, so the canvas does not tick frames for them.
final bool animated;