EffectEditing class final
The ranges an inspector offers for editing an effect's numeric properties.
Set through EffectDefinition.editing. Each EffectRange bounds only the inspector controls; each is validated when the definition is registered.
Constructors
- EffectEditing({EffectRange speed = const EffectRange(0.1, 5, 0.1), EffectRange baseOpacity = const EffectRange(0, 100, 5), EffectRange opacity = const EffectRange(0, 100, 5), EffectRange size = const EffectRange(1, 24, 1), EffectRange width = const EffectRange(1, 24, 1), EffectRange count = const EffectRange(1, 30, 1), EffectRange spread = const EffectRange(1, 48, 1), EffectRange amount = const EffectRange(0.5, 2, 0.02), EffectRange dim = const EffectRange(0, 100, 5), EffectRange delay = const EffectRange(0, 10, 0.1), EffectRange repeat = const EffectRange(1, 20, 1)})
-
const
Properties
- amount → EffectRange
-
Scale factors.
final
- baseOpacity → EffectRange
-
Opacities in percent.
final
- count → EffectRange
-
Counts: particles and cycles.
final
- delay → EffectRange
-
Speed in cycles per second, and delay in seconds.
final
- dim → EffectRange
-
Opacities in percent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opacity → EffectRange
-
Opacities in percent.
final
- repeat → EffectRange
-
Counts: particles and cycles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → EffectRange
-
Sizes in world units or logical pixels.
final
- speed → EffectRange
-
Speed in cycles per second, and delay in seconds.
final
- spread → EffectRange
-
Sizes in world units or logical pixels.
final
- width → EffectRange
-
Sizes in world units or logical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited