NumberValueField class final
A finite number field, optionally bounded by minimum and maximum and optionally restricted to integers.
- Inheritance
-
- Object
- ValueField
- NumberValueField
Constructors
- NumberValueField({required num defaultValue, num? minimum, num? maximum, bool integer = false})
-
const
Properties
- defaultValue → num
-
The value of a new shape. Null for a field every shape supplies, such
as a drawing's ink, or one that is empty until set, such as an image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- integer → bool
-
Restricts values to mathematically integral numbers, including 1.0.
final
- maximum → num?
-
final
- minimum → num?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accepts(
Object? value) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateDeclaration(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited