ResolvedConnectionPoint class final

A resolved magnet shared by pointer snapping and connection-point paint. Virtual points are projections, never hidden durable ports.

Constructors

ResolvedConnectionPoint({required ResolvedFramedElement shape, required BoundEndpoint endpoint, required DiagramPoint worldPosition})
const

Properties

endpoint → BoundEndpoint
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ResolvedFramedElement
final
worldPosition → DiagramPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited