routeStart property
Endpoints used to construct the route before clipping it to its owners. Bend gestures use this same basis so clipping cannot move the handle.
Implementation
final DiagramPoint routeStart;
Endpoints used to construct the route before clipping it to its owners. Bend gestures use this same basis so clipping cannot move the handle.
final DiagramPoint routeStart;