textFor method
The text filling the slot of paragraph, which decides what the
paragraph admits and how it edits.
Implementation
DiagramTextDefinition textFor(TextParagraph paragraph) =>
_textFor(paragraph.effectiveSlotId);
The text filling the slot of paragraph, which decides what the
paragraph admits and how it edits.
DiagramTextDefinition textFor(TextParagraph paragraph) =>
_textFor(paragraph.effectiveSlotId);