ResolvedShapePort class final

A port of a resolved shape, with its marker outline and the inset connectedOutline filled while a connector binds it.

Constructors

ResolvedShapePort({required PortDefinition definition, required ResolvedOutline outline, required ResolvedOutline connectedOutline})
const

Properties

connectedOutline → ResolvedOutline
The inset marker filled while a connector binds this port.
final
definition → PortDefinition
final
hashCode → int
The hash code for this object.
no setterinherited
localCenter → DiagramPoint
no setter
outline → ResolvedOutline
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hitTest(DiagramPoint localPoint, {double tolerance = 0}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited