behavior property
What a person may do to this element now: its declared behavior, narrowed while it is locked, collapsed or holds constraining content.
Implementation
@override
late final ShapeBehavior behavior = isLocked
? definition.behavior.locked
: definition.behavior;