collapsed property
ShapeBehavior
get
collapsed
A collapsed presentation cannot resize or rotate the preserved expanded frame, and its text does not size it.
Implementation
ShapeBehavior get collapsed => copyWith(
resizable: false,
rotatable: false,
textSizing: ShapeTextSizing.fixed,
);