ShapeCollapseDefinition class final
A container's compact presentation, such as a collapsed frame. Its body replaces the expanded body and may only reuse existing text slots.
Constructors
- ShapeCollapseDefinition({DiagramSize size = const DiagramSize(180, 80), ShapeStyle? style, ShapePart? body, CollapsedConnectionPresentation connections = CollapsedConnectionPresentation.separate})
-
const
Properties
- body → ShapePart?
-
final
- connections → CollapsedConnectionPresentation
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → DiagramSize
-
final
- style → ShapeStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited