affordances property
On-canvas controls beside the selected shape, such as a card's optional tag, each performing one of the shape's verbs.
Implementation
final List<ShapeAffordance> affordances;
On-canvas controls beside the selected shape, such as a card's optional tag, each performing one of the shape's verbs.
final List<ShapeAffordance> affordances;