outline property
The shape's own surface, or null for a shape that paints none, such as a group, an image or a comment drawn by its body.
Implementation
final ShapeOutline? outline;
The shape's own surface, or null for a shape that paints none, such as a group, an image or a comment drawn by its body.
final ShapeOutline? outline;