ShapeDividerLayerDefinition class final
A divider attached to one edge of its resolved bounds.
- Inheritance
-
- Object
- ShapeLayerDefinition
- ShapeDividerLayerDefinition
Constructors
- ShapeDividerLayerDefinition({required String id, required ShapeBoundsDefinition bounds, ShapeEdge edge = ShapeEdge.bottom, DiagramBorder? border})
-
const
Properties
- border → DiagramBorder?
-
final
- bounds → ShapeBoundsDefinition
-
finalinherited
- cursor → ShapeLayerCursor
-
no setterinherited
- edge → ShapeEdge
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- interactionId → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited