ShapeImageLayerDefinition class final
The image a shape stores in its ImageValueField valueKey, fitted to the region, or a placeholder while it has none.
- Inheritance
-
- Object
- ShapeLayerDefinition
- ShapeImageLayerDefinition
Constructors
- ShapeImageLayerDefinition({required String id, required ShapeBoundsDefinition bounds, required String valueKey})
-
const
Properties
- bounds → ShapeBoundsDefinition
-
finalinherited
- cursor → ShapeLayerCursor
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- interactionId → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueKey → String
-
final
Methods
-
imageIn(
Map< String, Object?> values) → DiagramImageSource? -
The image
valueshold under valueKey, if any. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited