vectorPathAt method

VectorPathOutline vectorPathAt(
  1. DiagramRect frame,
  2. ShapeStyle style,
  3. Map<String, Object?> values
)

This path outline at frame with its nodes kept, even when it resolves as a polygon, for editing it point by point.

Implementation

VectorPathOutline vectorPathAt(
  DiagramRect frame,
  ShapeStyle style,
  Map<String, Object?> values,
) => VectorPathOutline.local(
  frame,
  _path!(frame.size, values),
  cornerRadius: cornerRadius ? style.cornerRadius : 0,
);