ShapeWidgetRegistry class final
Immutable Flutter builders, separate from the pure shape grammar and document.
Constructors
-
ShapeWidgetRegistry(Map<
String, ShapeWidgetBuilder> builders) - ShapeWidgetRegistry.empty()
-
const
Properties
-
builders
→ Map<
String, ShapeWidgetBuilder> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
builderFor(
String key) → ShapeWidgetBuilder? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
require(
String key) → ShapeWidgetBuilder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited