ValueField class sealed
A declared field in a shape's durable custom content. Scalar fields support automatic controls; structured objects use host forms.
Properties
- defaultValue → Object?
-
The value of a new shape. Null for a field every shape supplies, such
as a drawing's ink, or one that is empty until set, such as an image.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accepts(
Object? value) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateDeclaration(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited