defaultValue property
Object?
get
defaultValue
The value of a new shape. Null for a field every shape supplies, such as a drawing's ink, or one that is empty until set, such as an image.
Implementation
Object? get defaultValue;