testing library
Keys that locate a canvas's surfaces in widget tests.
Constants
- diagramEditSurfaceKey → const Key
- Key of the surface a canvas mounts while it edits.
- diagramTextEditorKey → const Key
- Key of the in-place text editor while text is being edited. Its state is the platform TextInputClient.
- diagramViewSurfaceKey → const Key
- Key of the surface a canvas mounts while it only views.
Functions
-
editingExtension(
{List< DiagramTool> ? tools}) → DiagramFlutterExtension -
Makes a canvas edit, offering
toolsor every installed tool, without the editor's chrome: for widget tests of canvas editing.