DiagramVectorPath class final
Immutable editable path. A two-node open path is a line; a closed path requires at least three nodes. Only closed paths paint their fill.
Constructors
-
DiagramVectorPath({required Iterable<
DiagramPathNode> nodes, bool closed = false}) -
DiagramVectorPath.polyline(Iterable<
DiagramPoint> points, {bool closed = false}) -
factory
Properties
- closed → bool
-
final
- hashCode → int
-
The hash code for this object.
latefinal
-
nodes
→ List<
DiagramPathNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Iterable< DiagramPathNode> ? nodes, bool? closed}) → DiagramVectorPath -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toValue(
) → Map< String, Object?> - JSON-safe value stored under a PathValueField.
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromValue(
Object? value) → DiagramVectorPath? -
The valid path
valueholds, as written by toValue, or null.