ShapeStyle class final
Fill and stroke appearance of a ShapeElement.
Constructors
- ShapeStyle({DiagramFill fill = const DiagramColor(0xFFFFFFFF), DiagramColor stroke = const DiagramColor(0xFF111111), double strokeWidth = 2, double cornerRadius = 10, StrokeStyle strokeStyle = StrokeStyle.solid, InkPreset inkPreset = InkPreset.pen})
-
const
Properties
- cornerRadius → double
-
final
- fill → DiagramFill
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inkPreset → InkPreset
-
final
- isValid → bool
-
Value validity, independent of a shape's editable appearance controls.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stroke → DiagramColor
-
final
- strokeStyle → StrokeStyle
-
final
- strokeWidth → double
-
final
Methods
-
copyWith(
{DiagramFill? fill, DiagramColor? stroke, double? strokeWidth, double? cornerRadius, StrokeStyle? strokeStyle, InkPreset? inkPreset}) → ShapeStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Properties
-
fields
→ Map<
String, ValueField> -
Reusable field declarations for this aggregate; values remain in the style.
final